@@ -112,13 +112,16 @@ class CSVPath(click.Path):
 
     def convert(self, value, param, ctx):
         values = ()
+        repo_dirname = pre_commit_vauxoo.get_repo()
         for v in strcsv2tuple(value):
             try:
                 new_value = super().convert(v, param, ctx)
             except click.exceptions.BadParameter:
                 # The envvar are using path based on root repo path
-                new_value = os.path.join(pre_commit_vauxoo.get_repo(), v)
+                new_value = os.path.join(repo_dirname, v)
                 new_value = super().convert(new_value, param, ctx)
+            new_value = pre_commit_vauxoo.full_norm_path(new_value)
+            new_value = os.path.relpath(new_value, repo_dirname)
             values += (new_value,)
         return values
 
@@ -279,6 +282,25 @@ PRECOMMIT_HOOKS_TYPE += ["all"] + ["-%s" % i for i in PRECOMMIT_HOOKS_TYPE]
     "\f\nNow your command 'git commit' will run 'pre-commit-vauxoo' before to commit",
     **new_extra_kwargs,
 )
+@click.option(
+    "--version",
+    type=click.BOOL,
+    is_flag=True,
+    default=False,
+    help="Show the version of this package",
+    **new_extra_kwargs,
+)
+@click.option(
+    "--odoo-version",
+    envvar="VERSION",
+    type=click.STRING,
+    help="Odoo version used for the repository.",
+    **new_extra_kwargs,
+)
 def main(*args, **kwargs):
     """pre-commit-vauxoo run pre-commit with custom validations and configuration files"""
+    version = kwargs.pop("version", None)
+    if version:
+        pre_commit_vauxoo.show_version()
+        return
     pre_commit_vauxoo.main(*args, **kwargs)
