@@ -1,3 +1,5 @@
 export INCLUDE_LINT="src,tests,resources,setup.py,docs/conf.py"
 export PRECOMMIT_HOOKS_TYPE="all"
 export EXCLUDE_LINT="resources/module_warnings1"
+export EXCLUDE_AUTOFIX="resources/module_autofix1"
+export VERSION="16.0"
